@@ -1,3 +1,6 @@
+#![allow(clippy::unknown_clippy_lints)]
+#![allow(clippy::unnecessary_wraps)]
+
 use crate::common::*;
 
 use Function::*;
@@ -27,6 +30,7 @@ lazy_static! {
     ("os", Nullary(os)),
     ("os_family", Nullary(os_family)),
     ("parent_directory", Unary(parent_directory)),
+    ("quote", Unary(quote)),
     ("replace", Ternary(replace)),
     ("trim", Unary(trim)),
     ("trim_end", Unary(trim_end)),
@@ -206,6 +210,10 @@ fn parent_directory(_context: &FunctionContext, path: &str) -> Result<String, St
     .ok_or_else(|| format!("Could not extract parent directory from `{}`", path))
 }
 
+fn quote(_context: &FunctionContext, s: &str) -> Result<String, String> {
+  Ok(format!("'{}'", s.replace('\'', "'\\''")))
+}
+
 fn replace(_context: &FunctionContext, s: &str, from: &str, to: &str) -> Result<String, String> {
   Ok(s.replace(from, to))
 }
