@@ -24,6 +24,7 @@ mod init;
 mod interrupts;
 mod invocation_directory;
 mod json;
+mod line_prefixes;
 mod misc;
 mod positional_arguments;
 mod quiet;
@@ -39,4 +40,6 @@ mod sublime_syntax;
 mod subsequents;
 mod tempdir;
 mod undefined_variables;
+#[cfg(target_family = "windows")]
+mod windows_powershell;
 mod working_directory;
